bayespy.inference.vmp.nodes.gaussian_markov_chain.GaussianMarkovChainDistribution.compute_moments_and_cgf
=========================================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian_markov_chain

.. automethod:: GaussianMarkovChainDistribution.compute_moments_and_cgf